@@ -36,7 +36,9 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 
+#if defined(HAVE_GSTREAMER)
 #include <gst/gst.h>
+#endif
 
 #include <libtracker-miners-common/tracker-common.h>
 #include <libtracker-sparql/tracker-sparql.h>
@@ -451,7 +453,7 @@ check_eligible (TrackerIndexingTree *indexing_tree,
 	gboolean parents_indexable = TRUE;
 	gboolean is_dir;
 
-	controller = tracker_controller_new (indexing_tree, storage);
+	controller = tracker_controller_new (indexing_tree, storage, NULL);
 
 	/* Start check */
 	file = g_file_new_for_commandline_arg (eligible);
@@ -722,13 +724,14 @@ setup_connection (TrackerDomainOntology  *domain,
 
 	if (!dry_run)
 		store = get_cache_dir (domain);
-	ontology = tracker_domain_ontology_get_ontology (domain);
+	ontology = tracker_sparql_get_ontology_nepomuk ();
 	sparql_conn = tracker_sparql_connection_new (get_fts_connection_flags (),
 	                                             store,
 	                                             ontology,
 	                                             NULL,
 	                                             error);
 	g_clear_object (&store);
+	g_clear_object (&ontology);
 
 	return sparql_conn;
 }
@@ -777,7 +780,9 @@ main (gint argc, gchar *argv[])
 	/* Preempt possible registry updates, before tracker-extract-3 deals
 	 * with gstreamer plugins.
 	 */
+#if defined(HAVE_GSTREAMER)
 	gst_init (NULL, NULL);
+#endif
 
 	/* Translators: this messagge will apper immediately after the
 	 * usage string - Usage: COMMAND <THIS_MESSAGE>
@@ -884,7 +889,7 @@ main (gint argc, gchar *argv[])
 	                                       config,
 	                                       domain_ontology);
 
-	controller = tracker_controller_new (indexing_tree, storage);
+	controller = tracker_controller_new (indexing_tree, storage, files_interface);
 
 	proxy = tracker_miner_proxy_new (miner_files, connection, DBUS_PATH, NULL, &error);
 	if (error) {
